summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--taskflow/engines/action_engine/runner.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/taskflow/engines/action_engine/runner.py b/taskflow/engines/action_engine/runner.py
index f1f880c..d50de15 100644
--- a/taskflow/engines/action_engine/runner.py
+++ b/taskflow/engines/action_engine/runner.py
@@ -204,10 +204,10 @@ class _MachineBuilder(object):
LOG.debug("Entering new state '%s' in response to event '%s'",
new_state, event)
# NOTE(harlowja): when ran in debugging mode it is quite useful
# to track the various state transitions as they happen...
watchers = {}
- if LOG.isEnabledFor(logging.DEBUG):
+ if LOG.isEnabledFor(logging.BLATHER):
watchers['on_exit'] = on_exit
watchers['on_enter'] = on_enter
@@ -204,10 +204,10 @@ class _MachineBuilder(object):
LOG.debug("Entering new state '%s' in response to event '%s'",
new_state, event)
- # NOTE(harlowja): when ran in debugging mode it is quite useful
+ # NOTE(harlowja): when ran in blather mode it is quite useful
# to track the various state transitions as they happen...
watchers = {}